find_teenyc

Function find_teenyc 

pub fn find_teenyc() -> Result<PathBuf>
Resolve the teenyc binary to invoke.

Priority:

  1. $TEENYC_PATH, if set.
  2. The sole rustup-linked toolchain whose name contains teenyc — the naming convention cargo teeny install-toolchain uses (default toolchain name is <channel>-<host> with channel defaulting to stable-teenyc; see cargo-teeny’s install_toolchain module) — resolved to a binary path via rustup which --toolchain <name> teenyc.

This deliberately does not fall back further to a bare teenyc looked up on $PATH: that would only work by accident (most $PATHs don’t have a teenyc on them at all) and produces a worse error than pointing at the two supported setup paths.