copy_h_to_d

Function copy_h_to_d 

pub unsafe fn copy_h_to_d<T>(
    dst: DevicePtr,
    src: *const T,
    count: usize,
) -> Result<()>
Copy count elements of type T from host memory to device memory.

Safety

src must be valid for count reads. dst must be a valid device allocation of at least count * size_of::<T>() bytes.