pub fn launch_config(n_elements: usize, block_size: i32) -> CudaLaunchConfigExpand description
Build a launch config with an explicit block size.
Use when the block size is determined at the call site rather than from PTX metadata (e.g. when the grid is computed before the program is compiled).