pub fn f8_to_f32(byte: u8, variant: Fp8Variant) -> f32Expand description
Decodes an f8 byte (variant) back to f32. Unlike f32_to_f8, this fully handles
subnormals, since it may be asked to decode bytes this module didn’t itself produce.
pub fn f8_to_f32(byte: u8, variant: Fp8Variant) -> f32Decodes an f8 byte (variant) back to f32. Unlike f32_to_f8, this fully handles
subnormals, since it may be asked to decode bytes this module didn’t itself produce.