pub fn find_teenyc() -> Result<PathBuf>Expand description
Resolve the teenyc binary to invoke.
Priority:
$TEENYC_PATH, if set.- The sole
rustup-linked toolchain whose name containsteenyc— the naming conventioncargo teeny install-toolchainuses (default toolchain name is<channel>-<host>withchanneldefaulting tostable-teenyc; seecargo-teeny’sinstall_toolchainmodule) — resolved to a binary path viarustup which --toolchain <name> teenyc.
This deliberately does not fall back further to a bare teenyc looked up on $PATH: that
would only work by accident (most $PATHs don’t have a teenyc on them at all) and produces
a worse error than pointing at the two supported setup paths.