pub fn maxpool1d_backward<T: Triton, D: Num, const KL: i32, const STRIDE: i32, const BLOCK_OL: i32>(
dy_ptr: T::Pointer<D>,
x_ptr: T::Pointer<D>,
y_ptr: T::Pointer<D>,
dx_ptr: T::Pointer<D>,
_B: i32,
C: i32,
L: i32,
OL: i32,
)where
T::I32Tensor: Tensor<i32, 1> + Comparison<i32, BoolTensor = T::BoolTensor>,
T::Pointer<D>: AddOffsets<i32, 1, T::I32Tensor, Output = T::Tensor<T::Pointer<D>>>,Expand description
1-D max-pooling backward pass.
Re-scans the input window to find the max position, then scatters dy to
all input elements that equal the stored output maximum. dx must be
zero-initialised before launch.